Roster

Struct Roster 

pub struct Roster {
    pub ver: Option<String>,
    pub items: Vec<Item>,
}
The contact list of the user.

Fields

ver: Option<String>

Version of the contact list.

This is an opaque string that should only be sent back to the server on a new connection, if this client is storing the contact list between connections.

items: Vec<Item>

List of the contacts of the user.